@@ -1,4 +1,4 @@
-#' @title Repeated "Leave-location-and-time-out" resampling.
+#' @title (CAST) Repeated "leave-location-and-time-out" resampling
 #'
 #' @template rox_sptcv_cstf
 #'
@@ -28,50 +28,29 @@
 #' rrcv$instance # table
 ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
   inherit = mlr3::Resampling,
-
   public = list(
 
-    #' @field space_var `character(1)`\cr
-    #'   Column name identifying the spatial units.
-    space_var = NULL,
-
-    #' @field time_var `character(1)`\cr
-    #'  Column name identifying the temporal units.
-    time_var = NULL,
-
-    #' @field class `character(1)`\cr
-    #'  Column name identifying a class unit (e.g. land cover).
-    class = NULL,
-
     #' @description
     #' Create a "Spacetime Folds" resampling instance.
+    #'
+    #' For a list of available arguments, please see
+    #' [CAST::CreateSpacetimeFolds].
     #' @param id `character(1)`\cr
     #'   Identifier for the resampling strategy.
-    #' @param space_var `character(1)`\cr
-    #'   Column name identifying the spatial units.
-    #' @param time_var `character(1)`\cr
-    #'  Column name identifying the temporal units.
-    #' @param class `character(1)`\cr
-    #'  Column name identifying a class unit (e.g. land cover).
-    initialize = function(id = "repeated_sptcv_cstf",
-      space_var = NULL,
-      time_var = NULL,
-      class = NULL) {
-
+    initialize = function(id = "repeated_sptcv_cstf") {
       ps = ParamSet$new(params = list(
         ParamInt$new("folds", lower = 1L, default = 10L, tags = "required"),
-        ParamInt$new("repeats", lower = 1, default = 1L, tags = "required")
+        ParamInt$new("repeats", lower = 1, default = 1L, tags = "required"),
+        ParamUty$new("space_var", custom_check = function(x) check_character(x, len = 1)),
+        ParamUty$new("time_var", custom_check = function(x) check_character(x, len = 1)),
+        ParamUty$new("class", custom_check = function(x) check_character(x, len = 1))
       ))
       ps$values = list(folds = 10L, repeats = 1)
 
-      self$space_var = space_var
-      self$time_var = time_var
-      self$class = class
-
       super$initialize(
         id = id,
         param_set = ps,
-        man = "mlr3spatiotempcv::mlr_resamplings_repeated_SptCVCstf"
+        man = "mlr3spatiotempcv::mlr_resamplings_repeated_sptcv_cstf"
       )
     },
 
@@ -80,7 +59,7 @@ ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
     #'   Iteration number.
     folds = function(iters) {
       iters = assert_integerish(iters, any.missing = FALSE, coerce = TRUE)
-      ((iters - 1L) %% as.integer(self$param_set$values$repeats)) + 1L
+      ((iters - 1L) %% as.integer(self$param_set$values$folds)) + 1L
     },
 
     #' @description Translates iteration numbers to repetition number.
@@ -97,12 +76,14 @@ ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
     #'   A task to instantiate.
     instantiate = function(task) {
 
+      pv = self$param_set$values
+
       mlr3::assert_task(task)
       checkmate::assert_multi_class(task, c("TaskClassifST", "TaskRegrST"))
-      checkmate::assert_subset(self$time_var,
+      checkmate::assert_subset(pv$time_var,
         choices = task$feature_names,
         empty.ok = TRUE)
-      checkmate::assert_subset(self$space_var,
+      checkmate::assert_subset(pv$space_var,
         choices = task$feature_names,
         empty.ok = TRUE)
       groups = task$groups
@@ -111,14 +92,13 @@ ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
         stopf("Grouping is not supported for spatial resampling methods") # nocov
       }
 
-      private$.sample(task, self$space_var, self$time_var, self$class)
+      private$.sample(task)
 
       self$task_hash = task$hash
       self$task_nrow = task$nrow
       invisible(self)
     }
   ),
-
   active = list(
 
     #' @field iters `integer(1)`\cr
@@ -129,48 +109,42 @@ ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
       as.integer(pv$repeats) * as.integer(pv$folds)
     }
   ),
-
   private = list(
-    .sample = function(task, space_var, time_var, class) {
+    .sample = function(task) {
+      pv = self$param_set$values
 
-      reps = self$param_set$values$repeats
       # declare empty list so the for-loop can write to its fields
-      self$instance = vector("list", length = reps)
-
-      k = self$param_set$values$folds
-      data = task$data()
-
-      for (rep in seq_len(reps)) {
+      self$instance = vector("list", length = pv$repeats)
 
+      for (rep in seq_len(pv$repeats)) {
         sptfolds = sample_cstf(
-          self = self, task, space_var, time_var,
-          class, k, data)
+          self = self, task, pv$space_var, pv$time_var,
+          pv$class, pv$folds, task$data())
 
         # combine space and time folds
-        for (i in 1:k) {
-          if (!is.null(time_var) & !is.null(sptfolds$space_var)) {
+        for (i in 1:pv$folds) {
+          if (!is.null(pv$time_var) & !is.null(sptfolds$space_var)) {
             self$instance[[rep]]$test[[i]] = which(sptfolds$data[[sptfolds$space_var]] %in%
               sptfolds$spacefolds[[i]] &
-              sptfolds$data[[time_var]] %in% sptfolds$timefolds[[i]])
+              sptfolds$data[[pv$time_var]] %in% sptfolds$timefolds[[i]])
             self$instance[[rep]]$train[[i]] = which(!sptfolds$data[[sptfolds$space_var]] %in%
               sptfolds$spacefolds[[i]] &
-              sptfolds$data[[time_var]] %in% sptfolds$timefolds[[i]])
-          } else if (is.null(time_var) & !is.null(sptfolds$space_var)) {
+              sptfolds$data[[pv$time_var]] %in% sptfolds$timefolds[[i]])
+          } else if (is.null(pv$time_var) & !is.null(sptfolds$space_var)) {
             self$instance[[rep]]$test[[i]] = which(sptfolds$data[[sptfolds$space_var]] %in%
               sptfolds$spacefolds[[i]])
             self$instance[[rep]]$train[[i]] = which(!sptfolds$data[[sptfolds$space_var]] %in%
               sptfolds$spacefolds[[i]])
-          } else if (!is.null(time_var) & is.null(sptfolds$space_var)) {
-            self$instance[[rep]]$test[[i]] = which(sptfolds$data[[time_var]] %in%
+          } else if (!is.null(pv$time_var) & is.null(sptfolds$space_var)) {
+            self$instance[[rep]]$test[[i]] = which(sptfolds$data[[pv$time_var]] %in%
               sptfolds$timefolds[[i]])
-            self$instance[[rep]]$train[[i]] = which(!sptfolds$data[[time_var]] %in%
+            self$instance[[rep]]$train[[i]] = which(!sptfolds$data[[pv$time_var]] %in%
               sptfolds$timefolds[[i]])
           }
         }
       }
       invisible(self)
     },
-
     .get_train = function(i) {
       i = as.integer(i) - 1L
       folds = as.integer(self$param_set$values$folds)
@@ -178,7 +152,6 @@ ResamplingRepeatedSptCVCstf = R6Class("ResamplingRepeatedSptCVCstf",
       fold = i %% folds + 1L
       self$instance[[rep]]$train[[fold]]
     },
-
     .get_test = function(i) {
       i = as.integer(i) - 1L
       folds = as.integer(self$param_set$values$folds)
